==> haskell-test-framework-0.8.1.1-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework
version: 0.8.1.1
id: test-framework-0.8.1.1-jVXPZTswcZDeN85OGIrlV
key: test-framework-0.8.1.1-jVXPZTswcZDeN85OGIrlV
license: BSD3
maintainer: Libraries List <libraries@haskell.org>
homepage: https://batterseapower.github.io/test-framework/
synopsis: Framework for running and organising tests, with HUnit and QuickCheck support
description:
    Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
    parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
    command line options. All of this comes with colored test output, progress reporting and test statistics output.
category: Testing
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
exposed-modules:
    Test.Framework Test.Framework.Options Test.Framework.Providers.API
    Test.Framework.Runners.Console Test.Framework.Runners.Options
    Test.Framework.Runners.TestPattern Test.Framework.Runners.API
    Test.Framework.Seed
hidden-modules: Test.Framework.Core Test.Framework.Improving
                Test.Framework.Runners.Console.Colors
                Test.Framework.Runners.Console.ProgressBar
                Test.Framework.Runners.Console.Run
                Test.Framework.Runners.Console.Statistics
                Test.Framework.Runners.Console.Table
                Test.Framework.Runners.Console.Utilities
                Test.Framework.Runners.Core Test.Framework.Runners.Processors
                Test.Framework.Runners.Statistics Test.Framework.Runners.ThreadPool
                Test.Framework.Runners.TimedConsumption
                Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
                Test.Framework.Utilities
abi: a2c77da2e793f2716ac2db8b01fc4da6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/test-framework-0.8.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/test-framework-0.8.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/test-framework-0.8.1.1
hs-libraries: HStest-framework-0.8.1.1-jVXPZTswcZDeN85OGIrlV
depends:
    ansi-terminal-0.6.3.1-C5gpy392zkR1qCeRuDySE4
    ansi-wl-pprint-0.6.7.3-6GCcsFDbx2V8PibFjHfpG5 base-4.9.0.0
    containers-0.5.7.1 hostname-1.0-42Ipmmd3lMbCN35rV9k5gh
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    random-1.1-54KmMHXjttlERYcr1mvsAe
    regex-posix-0.95.2-Fy6xYMm8dnjHHt23b8RdmR time-1.6.0.1
    xml-1.3.14-9IpHbL0QRqR5eAZpdkwTMQ
haddock-interfaces: /usr/share/doc/haskell-test-framework/html/test-framework.haddock
haddock-html: /usr/share/doc/haskell-test-framework/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-0.8.1.1-9-i686.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework
version: 0.8.1.1
id: test-framework-0.8.1.1-KxfgUEp3rIgE0BNbPXb9Ta
key: test-framework-0.8.1.1-KxfgUEp3rIgE0BNbPXb9Ta
license: BSD3
maintainer: Libraries List <libraries@haskell.org>
homepage: https://batterseapower.github.io/test-framework/
synopsis: Framework for running and organising tests, with HUnit and QuickCheck support
description:
    Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
    parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
    command line options. All of this comes with colored test output, progress reporting and test statistics output.
category: Testing
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
exposed-modules:
    Test.Framework Test.Framework.Options Test.Framework.Providers.API
    Test.Framework.Runners.Console Test.Framework.Runners.Options
    Test.Framework.Runners.TestPattern Test.Framework.Runners.API
    Test.Framework.Seed
hidden-modules: Test.Framework.Core Test.Framework.Improving
                Test.Framework.Runners.Console.Colors
                Test.Framework.Runners.Console.ProgressBar
                Test.Framework.Runners.Console.Run
                Test.Framework.Runners.Console.Statistics
                Test.Framework.Runners.Console.Table
                Test.Framework.Runners.Console.Utilities
                Test.Framework.Runners.Core Test.Framework.Runners.Processors
                Test.Framework.Runners.Statistics Test.Framework.Runners.ThreadPool
                Test.Framework.Runners.TimedConsumption
                Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
                Test.Framework.Utilities
abi: 66c0967ce2506fac141a9584087e45c7
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/test-framework-0.8.1.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/test-framework-0.8.1.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/test-framework-0.8.1.1
hs-libraries: HStest-framework-0.8.1.1-KxfgUEp3rIgE0BNbPXb9Ta
depends:
    ansi-terminal-0.6.3.1-59sjf9WqHYuFAo9gQw9Bhp
    ansi-wl-pprint-0.6.7.3-7jqnIfTUHr2Bkg0VIWs8Q5 base-4.9.1.0
    containers-0.5.7.1 hostname-1.0-LHxcvBDHWay1RGMj1Uzenf
    old-locale-1.0.0.7-KGBP1BSKxH5GCm0LnZP04j
    random-1.1-9tceXaeYIMZ4JrKq20Egog
    regex-posix-0.95.2-KQJt29lnRa45d6bFn9XkFO time-1.6.0.1
    xml-1.3.14-FVnE0jAbj4fGGraldXZwwG
haddock-interfaces: /usr/share/doc/haskell-test-framework/html/test-framework.haddock
haddock-html: /usr/share/doc/haskell-test-framework/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
